/* This is a generated file, see Makefile.am for its inputs. */
static const char tcpoptname_strings[] = "TCP_AO_ADD_KEY\0TCP_AO_DEL_KEY\0TCP_AO_GET_KEYS\0TCP_AO_INFO\0TCP_AO_REPAIR\0TCP_CC_INFO\0TCP_CONGESTION\0TCP_COOKIE_TRANSACTIONS\0TCP_CORK\0TCP_DEFER_ACCEPT\0"
	"TCP_FASTOPEN\0TCP_FASTOPEN_CONNECT\0TCP_FASTOPEN_KEY\0TCP_FASTOPEN_NO_COOKIE\0TCP_INFO\0TCP_INQ\0TCP_KEEPCNT\0TCP_KEEPIDLE\0TCP_KEEPINTVL\0TCP_LINGER2\0"
	"TCP_MAXSEG\0TCP_MD5SIG\0TCP_MD5SIG_EXT\0TCP_NODELAY\0TCP_NOTSENT_LOWAT\0TCP_QUEUE_SEQ\0TCP_QUICKACK\0TCP_REPAIR\0TCP_REPAIR_OPTIONS\0TCP_REPAIR_QUEUE\0"
	"TCP_REPAIR_WINDOW\0TCP_SAVED_SYN\0TCP_SAVE_SYN\0TCP_SYNCNT\0TCP_THIN_DUPACK\0TCP_THIN_LINEAR_TIMEOUTS\0TCP_TIMESTAMP\0TCP_TX_DELAY\0TCP_ULP\0TCP_USER_TIMEOUT\0"
	"TCP_WINDOW_CLAMP\0TCP_ZEROCOPY_RECEIVE";
static const unsigned tcpoptname_i2s_direct[] = {
	328,291,123,252,265,240,477,279,132,581,
	223,372,84,302,99,504,488,564,385,415,
	358,396,149,529,340,72,464,450,432,162,
	556,313,183,200,598,232,543,0,15,46,
	30,58,
};
static const char *tcpoptname_i2s(int v) {
	return i2s_direct__(tcpoptname_strings, tcpoptname_i2s_direct, 1, 42, v);
}
