/* This is a generated file, see Makefile.am for its inputs. */
static const char bpf_strings[] = "BPF_BTF_GET_FD_BY_ID\0BPF_BTF_GET_NEXT_ID\0BPF_BTF_LOAD\0BPF_ENABLE_STATS\0BPF_ITER_CREATE\0BPF_LINK_CREATE\0BPF_LINK_DETACH\0BPF_LINK_GET_FD_BY_ID\0BPF_LINK_GET_NEXT_ID\0BPF_LINK_UPDATE\0"
	"BPF_MAP_CREATE\0BPF_MAP_DELETE_BATCH\0BPF_MAP_DELETE_ELEM\0BPF_MAP_FREEZE\0BPF_MAP_GET_FD_BY_ID\0BPF_MAP_GET_NEXT_ID\0BPF_MAP_GET_NEXT_KEY\0BPF_MAP_LOOKUP_AND_DELETE_BATCH\0BPF_MAP_LOOKUP_AND_DELETE_ELEM\0BPF_MAP_LOOKUP_BATCH\0"
	"BPF_MAP_LOOKUP_ELEM\0BPF_MAP_UPDATE_BATCH\0BPF_MAP_UPDATE_ELEM\0BPF_OBJ_GET\0BPF_OBJ_GET_INFO_BY_FD\0BPF_OBJ_PIN\0BPF_PROG_ATTACH\0BPF_PROG_BIND_MAP\0BPF_PROG_DETACH\0BPF_PROG_GET_FD_BY_ID\0"
	"BPF_PROG_GET_NEXT_ID\0BPF_PROG_LOAD\0BPF_PROG_QUERY\0BPF_PROG_TEST_RUN\0BPF_RAW_TRACEPOINT_OPEN\0BPF_TASK_FD_QUERY";
static const unsigned bpf_i2s_direct[] = {
	178,395,436,214,290,596,491,456,503,537,
	625,575,270,553,249,468,610,643,41,0,
	667,343,234,21,374,311,415,193,87,162,
	119,141,54,71,103,519,
};
static const char *bpf_i2s(int v) {
	return i2s_direct__(bpf_strings, bpf_i2s_direct, 0, 35, v);
}
