/* This is a generated file, see Makefile.am for its inputs. */
static const char uringop_strings[] = "accept\0bind\0close\0connect\0fallocate\0fgetxattr\0fixed_fd_install\0fsetxattr\0ftruncate\0futex_wait\0"
	"futex_waitv\0futex_wake\0getxattr\0linkat\0listen\0mkdirat\0msg_ring\0openat\0openat2\0recvmsg\0"
	"renameat\0sendmsg\0sendmsg_zc\0setxattr\0shutdown\0symlinkat\0unlinkat\0uring_cmd\0uring_cmd128\0waitid";
static const unsigned uringop_s2i_s[] = {
	0,7,12,18,26,36,46,63,73,83,
	94,106,117,126,133,140,148,157,164,172,
	180,189,197,208,217,226,236,245,255,268,
};
static const int uringop_s2i_i[] = {
	13,56,19,16,17,43,54,41,55,51,
	53,52,44,39,57,37,40,18,28,10,
	35,9,48,42,34,38,36,46,64,50,
};
static int uringop_s2i(const char *s, int *value) {
	size_t len, i;
	 if (s == NULL || value == NULL)
		return 0;
	len = strlen(s);
	{ char copy[len + 1];
	for (i = 0; i < len; i++) {
		char c = s[i];
		copy[i] = GT_ISUPPER(c) ? c - 'A' + 'a' : c;
	}
	copy[i] = 0;
	return s2i__(uringop_strings, uringop_s2i_s, uringop_s2i_i, 30, copy, value);
	}
}
static const unsigned uringop_i2s_direct[] = {
	189,172,-1u,-1u,0,-1u,-1u,18,26,157,
	12,-1u,-1u,-1u,-1u,-1u,-1u,-1u,-1u,164,
	-1u,-1u,-1u,-1u,-1u,217,180,236,140,226,
	126,148,63,208,36,117,-1u,245,-1u,197,
	-1u,268,83,106,94,46,73,7,133,-1u,
	-1u,-1u,-1u,-1u,-1u,255,
};
static const char *uringop_i2s(int v) {
	return i2s_direct__(uringop_strings, uringop_i2s_direct, 9, 64, v);
}
