/* This is a generated file, see Makefile.am for its inputs. */
static const char ptrace_strings[] = "PTRACE_ARCH_PRCTL\0PTRACE_ATTACH\0PTRACE_CONT\0PTRACE_DETACH\0PTRACE_GETEVENTMSG\0PTRACE_GETFPREGS\0PTRACE_GETFPXREGS\0PTRACE_GETREGS\0PTRACE_GETREGSET\0PTRACE_GETSIGINFO\0"
	"PTRACE_GETSIGMASK\0PTRACE_GET_RSEQ_CONFIGURATION\0PTRACE_GET_SYSCALL_INFO\0PTRACE_GET_SYSCALL_USER_DISPATCH_CONFIG\0PTRACE_GET_THREAD_AREA\0PTRACE_INTERRUPT\0PTRACE_KILL\0PTRACE_LISTEN\0PTRACE_PEEKDATA\0PTRACE_PEEKSIGINFO\0"
	"PTRACE_PEEKTEXT\0PTRACE_PEEKUSER\0PTRACE_POKEDATA\0PTRACE_POKETEXT\0PTRACE_POKEUSER\0PTRACE_SECCOMP_GET_FILTER\0PTRACE_SECCOMP_GET_METADATA\0PTRACE_SEIZE\0PTRACE_SETFPREGS\0PTRACE_SETFPXREGS\0"
	"PTRACE_SETOPTIONS\0PTRACE_SETREGS\0PTRACE_SETREGSET\0PTRACE_SETSIGINFO\0PTRACE_SETSIGMASK\0PTRACE_SET_SYSCALL_USER_DISPATCH_CONFIG\0PTRACE_SET_THREAD_AREA\0PTRACE_SINGLEBLOCK\0PTRACE_SINGLESTEP\0PTRACE_SYSCALL\0"
	"PTRACE_SYSEMU\0PTRACE_SYSEMU_SINGLESTEP\0PTRACE_TRACEME";
static const int ptrace_i2s_i[] = {
	0,1,2,3,4,5,6,7,8,9,
	12,13,14,15,16,17,18,19,24,25,
	26,30,31,32,33,16896,16897,16898,16899,16900,
	16901,16902,16903,16904,16905,16906,16907,16908,16909,16910,
	16911,16912,16913,
};
static const unsigned ptrace_i2s_s[] = {
	797,375,340,391,423,407,439,32,314,725,
	112,575,77,522,18,44,94,539,743,274,
	683,0,758,772,706,557,58,144,607,127,
	590,509,297,326,356,162,625,455,481,210,
	180,643,234,
};
static const char *ptrace_i2s(int v) {
	return i2s_bsearch__(ptrace_strings, ptrace_i2s_i, ptrace_i2s_s, 43, v);
}
