/* This is a generated file, see Makefile.am for its inputs. */
static const char openat2_resolve_strings[] = "RESOLVE_BENEATH\0RESOLVE_CACHED\0RESOLVE_IN_ROOT\0RESOLVE_NO_MAGICLINKS\0RESOLVE_NO_SYMLINKS\0RESOLVE_NO_XDEV";
static const struct transtab openat2_resolve_table[] = {
	{1,89},{2,47},{4,69},{8,0},{16,31},{32,16},
};
#define OPENAT2_RESOLVE_NUM_ENTRIES (sizeof(openat2_resolve_table) / sizeof(*openat2_resolve_table))
