/* This is a generated file, see Makefile.am for its inputs. */
static const char xattr_atflag_strings[] = "AT_EMPTY_PATH\0AT_NO_AUTOMOUNT\0AT_RECURSIVE\0AT_SYMLINK_NOFOLLOW";
static const struct transtab xattr_atflag_table[] = {
	{256,43},{2048,14},{4096,0},{32768,30},
};
#define XATTR_ATFLAG_NUM_ENTRIES (sizeof(xattr_atflag_table) / sizeof(*xattr_atflag_table))
