/* This is a generated file, see Makefile.am for its inputs. */
static const char ipccmd_strings[] = "IPC_CREAT\0IPC_EXCL\0IPC_NOWAIT";
static const struct transtab ipccmd_table[] = {
	{512,0},{1024,10},{2048,19},
};
#define IPCCMD_NUM_ENTRIES (sizeof(ipccmd_table) / sizeof(*ipccmd_table))
