/* This is a generated file, see Makefile.am for its inputs. */
static const char pktoptname_strings[] = "PACKET_ADD_MEMBERSHIP\0PACKET_AUXDATA\0PACKET_COPY_THRESH\0PACKET_DROP_MEMBERSHIP\0PACKET_FANOUT\0PACKET_FANOUT_DATA\0PACKET_HDRLEN\0PACKET_IGNORE_OUTGOING\0PACKET_LOSS\0PACKET_ORIGDEV\0"
	"PACKET_QDISC_BYPASS\0PACKET_RECV_OUTPUT\0PACKET_RESERVE\0PACKET_ROLLOVER_STATS\0PACKET_RX_RING\0PACKET_STATISTICS\0PACKET_TIMESTAMP\0PACKET_TX_HAS_OFF\0PACKET_TX_RING\0PACKET_TX_TIMESTAMP\0"
	"PACKET_VERSION\0PACKET_VNET_HDR\0PACKET_VNET_HDR_SZ";
static const unsigned pktoptname_i2s_direct[] = {
	0,56,196,-1u,252,267,37,22,161,355,
	112,215,320,149,370,335,285,79,302,176,
	230,93,126,386,
};
static const char *pktoptname_i2s(int v) {
	return i2s_direct__(pktoptname_strings, pktoptname_i2s_direct, 1, 24, v);
}
