/* This is a generated file, see Makefile.am for its inputs. */
static const char recv_strings[] = "MSG_BATCH\0MSG_CMSG_CLOEXEC\0MSG_CMSG_COMPAT\0MSG_CONFIRM\0MSG_CTRUNC\0MSG_DONTROUTE\0MSG_DONTWAIT\0MSG_EOR\0MSG_ERRQUEUE\0MSG_FASTOPEN\0"
	"MSG_FIN\0MSG_MORE\0MSG_NOSIGNAL\0MSG_OOB\0MSG_PEEK\0MSG_PROXY\0MSG_RST\0MSG_SENDPAGE_NOTLAST\0MSG_SYN\0MSG_TRUNC\0"
	"MSG_WAITALL\0MSG_WAITFORONE";
static const struct transtab recv_table[] = {
	{1,157},{2,165},{4,66},{8,55},{16,174},{32,221},{64,80},{128,93},{256,231},{512,127},
	{1024,213},{2048,43},{4096,184},{8192,101},{16384,144},{32768,135},{65536,243},{131072,192},{262144,0},{536870912,114},
	{1073741824,10},{-2147483648,27},
};
#define RECV_NUM_ENTRIES (sizeof(recv_table) / sizeof(*recv_table))
