/* This is a generated file, see Makefile.am for its inputs. */
static const char sockoptname_strings[] = "SCM_TIMESTAMPING_OPT_STATS\0SCM_TIMESTAMPING_PKTINFO\0SO_ACCEPTCONN\0SO_ATTACH_BPF\0SO_ATTACH_FILTER\0SO_ATTACH_REUSEPORT_CBPF\0SO_ATTACH_REUSEPORT_EBPF\0SO_BINDTODEVICE\0SO_BINDTOIFINDEX\0SO_BPF_EXTENSIONS\0"
	"SO_BROADCAST\0SO_BSDCOMPAT\0SO_BUF_LOCK\0SO_BUSY_POLL\0SO_BUSY_POLL_BUDGET\0SO_CNX_ADVICE\0SO_COOKIE\0SO_DEBUG\0SO_DETACH_FILTER\0SO_DETACH_REUSEPORT_BPF\0"
	"SO_DOMAIN\0SO_DONTROUTE\0SO_ERROR\0SO_INCOMING_CPU\0SO_INCOMING_NAPI_ID\0SO_KEEPALIVE\0SO_LINGER\0SO_LOCK_FILTER\0SO_MARK\0SO_MAX_PACING_RATE\0"
	"SO_MEMINFO\0SO_NETNS_COOKIE\0SO_NOFCS\0SO_NO_CHECK\0SO_OOBINLINE\0SO_PASSCRED\0SO_PASSCRED\0SO_PASSPIDFD\0SO_PASSSEC\0SO_PEEK_OFF\0"
	"SO_PEERCRED\0SO_PEERCRED\0SO_PEERGROUPS\0SO_PEERNAME\0SO_PEERPIDFD\0SO_PEERSEC\0SO_PREFER_BUSY_POLL\0SO_PRIORITY\0SO_PROTOCOL\0SO_RCVBUF\0"
	"SO_RCVBUFFORCE\0SO_RCVLOWAT\0SO_RCVLOWAT\0SO_RCVMARK\0SO_RCVTIMEO\0SO_RCVTIMEO\0SO_RCVTIMEO_NEW\0SO_RESERVE_MEM\0SO_REUSEADDR\0SO_REUSEPORT\0"
	"SO_RXQ_OVFL\0SO_SECURITY_AUTHENTICATION\0SO_SECURITY_ENCRYPTION_NETWORK\0SO_SECURITY_ENCRYPTION_TRANSPORT\0SO_SELECT_ERR_QUEUE\0SO_SNDBUF\0SO_SNDBUFFORCE\0SO_SNDLOWAT\0SO_SNDLOWAT\0SO_SNDTIMEO\0"
	"SO_SNDTIMEO\0SO_SNDTIMEO_NEW\0SO_TIMESTAMP\0SO_TIMESTAMPING\0SO_TIMESTAMPING_NEW\0SO_TIMESTAMPNS\0SO_TIMESTAMPNS_NEW\0SO_TIMESTAMP_NEW\0SO_TXREHASH\0SO_TXTIME\0"
	"SO_TYPE\0SO_WIFI_STATUS\0SO_ZEROCOPY";
static const unsigned sockoptname_i2s_direct[] = {
	293,830,1190,366,353,198,979,715,411,524,
	512,691,424,211,843,537,597,740,1004,775,
	1028,868,926,895,147,80,302,635,1068,52,
	660,989,725,574,1117,449,1081,703,343,856,
	1198,585,503,434,959,236,457,180,375,66,
	97,122,269,0,476,391,283,27,621,1213,
	1180,163,1151,1132,1097,799,1052,319,671,249,
	487,224,815,1168,764,561,647,-1u,-1u,-1u,
	-1u,-1u,-1u,-1u,-1u,-1u,-1u,-1u,-1u,-1u,
	-1u,-1u,-1u,-1u,-1u,-1u,-1u,-1u,-1u,-1u,
	-1u,-1u,-1u,-1u,-1u,-1u,-1u,-1u,-1u,-1u,
	-1u,-1u,-1u,-1u,-1u,752,1016,787,1040,549,
	609,
};
static const char *sockoptname_i2s(int v) {
	return i2s_direct__(sockoptname_strings, sockoptname_i2s_direct, 1, 121, v);
}
