/* This is a generated file, see Makefile.am for its inputs. */
static const char umount_strings[] = "MNT_DETACH\0MNT_EXPIRE\0MNT_FORCE\0UMOUNT_NOFOLLOW\0UMOUNT_UNUSED";
static const struct transtab umount_table[] = {
	{1,22},{2,0},{4,11},{8,32},{-2147483648,48},
};
#define UMOUNT_NUM_ENTRIES (sizeof(umount_table) / sizeof(*umount_table))
