/* This is a generated file, see Makefile.am for its inputs. */
static const char mmap_strings[] = "MAP_32BIT\0MAP_ANONYMOUS\0MAP_DENYWRITE\0MAP_EXECUTABLE\0MAP_FIXED\0MAP_FIXED_NOREPLACE\0MAP_GROWSDOWN\0MAP_HUGETLB\0MAP_LOCKED\0MAP_NONBLOCK\0"
	"MAP_NORESERVE\0MAP_POPULATE\0MAP_PRIVATE\0MAP_SHARED\0MAP_STACK\0MAP_SYNC\0MAP_UNINITIALIZED";
static const struct transtab mmap_table[] = {
	{1,172},{2,160},{16,53},{32,10},{64,0},{256,83},{2048,24},{4096,38},{8192,109},{16384,133},
	{32768,147},{65536,120},{131072,183},{262144,97},{524288,193},{1048576,63},{67108864,202},
};
#define MMAP_NUM_ENTRIES (sizeof(mmap_table) / sizeof(*mmap_table))
