/* This is a generated file, see Makefile.am for its inputs. */
static const char arphook_strings[] = "FORWARD\0INPUT\0OUTPUT";
static const unsigned arphook_i2s_direct[] = {
	8,14,0,
};
static const char *arphook_i2s(int v) {
	return i2s_direct__(arphook_strings, arphook_i2s_direct, 0, 2, v);
}
