/* This is a generated file, see Makefile.am for its inputs. */
static const char access_strings[] = "R_OK\0W_OK\0X_OK";
static const struct transtab access_table[] = {
	{1,10},{2,5},{4,0},
};
#define ACCESS_NUM_ENTRIES (sizeof(access_table) / sizeof(*access_table))
