/* This is a generated file, see Makefile.am for its inputs. */
static const char ioctlreq_strings[] = "CDROMEJECT\0CDROMEJECT_SW\0CDROMSEEK\0CDROM_GET_UPC\0DRM_IOCTL_MODE_CURSOR\0DRM_IOCTL_MODE_DIRTYFB\0DRM_IOCTL_MODE_PAGE_FLIP\0FIOGETOWN\0FIONBIO\0FIOSETOWN\0"
	"KDGETMODE\0KDSETMODE\0SIOCBRADDIF\0SIOCGIFHWADDR\0SIOCGIFINDEX\0SIOCGIFNAME\0TCFLSH\0TCGETS\0TCSBRK\0TCSETS\0"
	"TCSETSF\0TCSETSW\0TIOCGPGRP\0TIOCGPTN\0TIOCGWINSZ\0TIOCINQ\0TIOCNOTTY\0TIOCSCTTY\0TIOCSPGRP\0TIOCSPTLCK\0"
	"TIOCSPTLCK\0TIOCSWINSZ";
static const int ioctlreq_i2s_i[] = {
	-2147199952,-2147199951,-1072143184,-1072143183,-1071881053,19258,19259,21257,21263,21265,
	21270,21505,21506,21507,21508,21513,21515,21518,21519,21520,
	21523,21524,21531,21537,21538,35073,35075,35088,35111,35123,
	35234,1074025521,
};
static const unsigned ioctlreq_i2s_s[] = {
	272,341,94,71,49,157,147,0,11,35,
	25,225,239,254,246,232,218,310,262,320,
	281,352,292,129,300,137,119,206,179,193,
	167,330,
};
static const char *ioctlreq_i2s(int v) {
	return i2s_bsearch__(ioctlreq_strings, ioctlreq_i2s_i, ioctlreq_i2s_s, 32, v);
}
