/* This is a generated file, see Makefile.am for its inputs. */
static const char normalize_syscall_map_strings[] = "accept\0accept4\0access\0adjtimex\0bind\0brk\0chmod\0chown\0clock_settime\0clock_settime64\0"
	"connect\0creat\0delete_module\0execve\0execveat\0faccessat\0faccessat2\0fallocate\0fchmod\0fchmodat\0"
	"fchmodat2\0fchown\0fchownat\0fchownat2\0file_getattr\0file_setattr\0finit_module\0fremovexattr\0fsconfig\0fsetxattr\0"
	"fsmount\0fsopen\0fspick\0fstat\0fstatfs\0ftruncate\0futimesat\0getxattrat\0init_module\0kill\0"
	"landlock_add_rule\0landlock_create_ruleset\0landlock_restrict_self\0lchown\0listxattrat\0lremovexattr\0lsetxattr\0lsm_get_self_attr\0lsm_list_modules\0lsm_set_self_attr\0"
	"lstat\0memfd_create\0memfd_secret\0mkdir\0mkdirat\0mknod\0mknodat\0mmap\0mount\0mount_setattr\0"
	"move_mount\0mseal\0newfstatat\0open\0open_by_handle_at\0open_tree_attr\0openat\0openat2\0pidfd_getfd\0readlink\0"
	"readlinkat\0recvfrom\0recvmsg\0removexattr\0removexattrat\0rename\0renameat\0renameat2\0rmdir\0sched_setattr\0"
	"sched_setparam\0sched_setscheduler\0sendmsg\0sendto\0setdomainname\0setegid\0seteuid\0setfsgid\0setfsuid\0setgid\0"
	"sethostname\0setregid\0setresgid\0setresuid\0setreuid\0settimeofday\0setuid\0setxattr\0setxattrat\0stat\0"
	"stat64\0statfs\0statmount\0statx\0stime\0symlink\0symlinkat\0tgkill\0tkill\0truncate\0"
	"umount\0umount2\0unlink\0unlinkat\0utime\0utimensat\0utimes";
static const unsigned normalize_syscall_map_s2i_s[] = {
	0,7,15,22,31,36,40,46,52,66,
	82,90,96,110,117,126,136,147,157,164,
	173,183,190,199,209,222,235,248,261,270,
	280,288,295,302,308,316,326,336,347,359,
	364,382,406,429,436,448,461,471,489,506,
	524,530,543,556,562,570,576,584,589,595,
	609,620,626,637,642,660,675,682,690,702,
	711,722,731,739,751,765,772,781,791,797,
	811,826,845,853,860,874,882,890,899,908,
	915,927,936,946,956,965,978,985,994,1005,
	1010,1017,1024,1034,1040,1046,1054,1064,1071,1077,
	1086,1093,1101,1108,1117,1123,1133,
};
static const int normalize_syscall_map_s2i_i[] = {
	16,16,10,31,17,35,3,4,31,31,
	18,1,6,15,15,10,10,1,3,3,
	3,4,4,4,10,2,5,2,8,2,
	8,8,8,10,34,1,14,10,5,21,
	40,40,40,4,10,2,2,41,42,40,
	10,1,1,7,7,32,32,35,8,2,
	8,40,10,1,1,1,1,1,1,1,
	1,19,19,2,2,9,9,9,13,36,
	36,36,20,20,33,30,29,30,29,30,
	33,30,30,29,29,31,29,2,2,10,
	10,34,34,10,31,11,11,21,21,1,
	12,12,13,13,14,14,14,
};
static int normalize_syscall_map_s2i(const char *s, int *value) {
	size_t len, i;
	 if (s == NULL || value == NULL)
		return 0;
	len = strlen(s);
	{ char copy[len + 1];
	for (i = 0; i < len; i++) {
		char c = s[i];
		copy[i] = GT_ISUPPER(c) ? c - 'A' + 'a' : c;
	}
	copy[i] = 0;
	return s2i__(normalize_syscall_map_strings, normalize_syscall_map_s2i_s, normalize_syscall_map_s2i_i, 117, copy, value);
	}
}
