/* This is a generated file, see Makefile.am for its inputs. */
static const char access_flag_strings[] = "AT_EACCESS\0AT_EMPTY_PATH\0AT_SYMLINK_NOFOLLOW";
static const struct transtab access_flag_table[] = {
	{256,25},{512,0},{4096,11},
};
#define ACCESS_FLAG_NUM_ENTRIES (sizeof(access_flag_table) / sizeof(*access_flag_table))
