/* This is a generated file, see Makefile.am for its inputs. */
static const char socklevel_strings[] = "SOL_AAL\0SOL_ALG\0SOL_ATALK\0SOL_ATM\0SOL_AX25\0SOL_BLUETOOTH\0SOL_CAIF\0SOL_DCCP\0SOL_DECNET\0SOL_ICMPV6\0"
	"SOL_IP\0SOL_IPV6\0SOL_IPX\0SOL_IRDA\0SOL_IUCV\0SOL_KCM\0SOL_LLC\0SOL_MCTP\0SOL_MPTCP\0SOL_NETBEUI\0"
	"SOL_NETLINK\0SOL_NETROM\0SOL_NFC\0SOL_PACKET\0SOL_PNPIPE\0SOL_PPPOL2TP\0SOL_RAW\0SOL_RDS\0SOL_ROSE\0SOL_RXRPC\0"
	"SOL_SCTP\0SOL_SMC\0SOL_TCP\0SOL_TIPC\0SOL_TLS\0SOL_UDP\0SOL_UDPLITE\0SOL_VSOCK\0SOL_XDP";
static const int socklevel_i2s_i[] = {
	0,6,17,41,58,132,136,255,256,257,
	258,259,260,261,263,264,265,266,267,268,
	269,270,271,272,273,274,275,276,277,278,
	279,280,281,282,283,284,285,286,287,
};
static const unsigned socklevel_i2s_s[] = {
	97,304,329,104,86,287,337,252,113,34,
	16,198,268,75,217,26,0,121,174,147,
	66,186,312,277,239,43,228,260,130,57,
	8,209,139,321,359,164,155,296,349,
};
static const char *socklevel_i2s(int v) {
	return i2s_bsearch__(socklevel_strings, socklevel_i2s_i, socklevel_i2s_s, 39, v);
}
