/* This is a generated file, see Makefile.am for its inputs. */
static const char ipoptname_strings[] = "IPT_SO_GET_REVISION_TARGET\0IPT_SO_SET_ADD_COUNTERS\0IPT_SO_SET_REPLACE\0IP_ADD_MEMBERSHIP\0IP_ADD_SOURCE_MEMBERSHIP\0IP_BIND_ADDRESS_NO_PORT\0IP_BLOCK_SOURCE\0IP_CHECKSUM\0IP_DROP_MEMBERSHIP\0IP_DROP_SOURCE_MEMBERSHIP\0"
	"IP_FREEBIND\0IP_HDRINCL\0IP_IPSEC_POLICY\0IP_LOCAL_PORT_RANGE\0IP_MINTTL\0IP_MSFILTER\0IP_MTU\0IP_MTU_DISCOVER\0IP_MULTICAST_ALL\0IP_MULTICAST_IF\0"
	"IP_MULTICAST_LOOP\0IP_MULTICAST_TTL\0IP_NODEFRAG\0IP_OPTIONS\0IP_ORIGDSTADDR\0IP_PASSSEC\0IP_PKTINFO\0IP_PKTOPTIONS\0IP_PROTOCOL\0IP_RECVERR\0"
	"IP_RECVFRAGSIZE\0IP_RECVOPTS\0IP_RECVTOS\0IP_RECVTTL\0IP_RETOPTS\0IP_ROUTER_ALERT\0IP_TOS\0IP_TRANSPARENT\0IP_TTL\0IP_UNBLOCK_SOURCE\0"
	"IP_UNICAST_IF\0IP_XFRM_POLICY\0MCAST_BLOCK_SOURCE\0MCAST_JOIN_GROUP\0MCAST_JOIN_SOURCE_GROUP\0MCAST_LEAVE_GROUP\0MCAST_LEAVE_SOURCE_GROUP\0MCAST_MSFILTER\0MCAST_UNBLOCK_SOURCE";
static const unsigned ipoptname_i2s_direct[] = {
	556,578,222,394,540,495,529,431,442,298,
	468,518,507,291,210,233,617,420,563,405,
	269,382,153,113,479,-1u,-1u,-1u,-1u,-1u,
	-1u,331,365,347,70,165,585,137,88,184,
	279,651,632,750,692,668,710,735,314,603,
	249,456,-1u,-1u,-1u,-1u,-1u,-1u,-1u,-1u,
	-1u,-1u,-1u,51,27,0,
};
static const char *ipoptname_i2s(int v) {
	return i2s_direct__(ipoptname_strings, ipoptname_i2s_direct, 1, 66, v);
}
