/* This is a generated file, see Makefile.am for its inputs. */
#include <inttypes.h>
static const char clone_flag_strings[] = "CLONE_CHILD_CLEARTID\0CLONE_CHILD_SETTID\0CLONE_CLEAR_SIGHAND\0CLONE_DETACHED\0CLONE_FILES\0CLONE_FS\0CLONE_INTO_CGROUP\0CLONE_IO\0CLONE_NEWIPC\0CLONE_NEWNET\0"
	"CLONE_NEWNS\0CLONE_NEWPID\0CLONE_NEWUSER\0CLONE_NEWUTS\0CLONE_PARENT\0CLONE_PARENT_SETTID\0CLONE_PTRACE\0CLONE_SETTLS\0CLONE_SIGHAND\0CLONE_STOPPED\0"
	"CLONE_SYSVSEM\0CLONE_THREAD\0CLONE_UNTRACED\0CLONE_VFORK\0CLONE_VM";
static const struct transtab64 clone_flag_table[] = {
	{256,342},{512,87},{1024,75},{2048,260},{8192,234},{16384,330},{32768,201},{65536,302},{131072,149},{262144,288},
	{524288,247},{1048576,214},{2097152,0},{4194304,60},{8388608,315},{16777216,21},{33554432,274},{67108864,188},{134217728,123},{268435456,174},
	{536870912,161},{1073741824,136},{2147483648,114},{4294967296,40},{8589934592,96},
};
#define CLONE_FLAG_NUM_ENTRIES (sizeof(clone_flag_table) / sizeof(*clone_flag_table))
